@@ -1065,6 +1065,9 @@ class Template(object):
                                 results.add(v[0])
                                 results = results.union(get_conditions_from_property(v[1]))
                                 results = results.union(get_conditions_from_property(v[2]))
+            elif isinstance(value, list):
+                for v in value:
+                    results = results.union(get_conditions_from_property(v))
 
             return results
 
@@ -1224,7 +1227,7 @@ class ParseError(cfnlint.CloudFormationLintRule):
     id = 'E0000'
     shortdesc = 'Parsing error found when parsing the template'
     description = 'Checks for Null values and Duplicate values in resources'
-    source_url = 'https://github.com/awslabs/cfn-python-lint'
+    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint'
     tags = ['base']
 
 class TransformError(cfnlint.CloudFormationLintRule):
@@ -1232,7 +1235,7 @@ class TransformError(cfnlint.CloudFormationLintRule):
     id = 'E0001'
     shortdesc = 'Error found when transforming the template'
     description = 'Errors found when performing transformation on the template'
-    source_url = 'https://github.com/awslabs/cfn-python-lint'
+    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint'
     tags = ['base', 'transform']
 
 class RuleError(cfnlint.CloudFormationLintRule):
@@ -1240,5 +1243,5 @@ class RuleError(cfnlint.CloudFormationLintRule):
     id = 'E0002'
     shortdesc = 'Error processing rule on the template'
     description = 'Errors found when processing a rule on the template'
-    source_url = 'https://github.com/awslabs/cfn-python-lint'
+    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint'
     tags = ['base', 'rule']
