@@ -27,7 +27,7 @@ class ValuePrimitiveType(CloudFormationLintRule):
     shortdesc = 'Check resource properties values'
     description = 'Checks resource property values with Primitive Types for ' \
                   'values that match those types.'
-    source_url = 'https://github.com/awslabs/cfn-python-lint/blob/master/docs/cfn-resource-specification.md#valueprimitivetype'
+    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint/blob/master/docs/cfn-resource-specification.md#valueprimitivetype'
     tags = ['resources']
 
     def __init__(self):
